{% extends "allianceauth/base.html" %}
{% load static %}
{% load i18n %}

{% block page_title %}{% translate "Services Management" %}{% endblock page_title %}
{% block extra_css %}{% endblock extra_css %}

{% block content %}
    <div class="clearfix">
        <h1 class="page-header text-center">{% translate "Available Services" %}</h1>

        <div class="panel panel-default">
            <div class="panel-heading aa-fleetpings-ping-header">
                <div class="panel-title">{% translate "Your Services" %}</div>
            </div>
            <div class="panel-body">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th class="text-center">{% translate "Service" %}</th>
                            <th class="text-center">{% translate "Username" %}</th>
                            <th class="text-center">{% translate "Domain" %}</th>
                            <th class="text-center">{% translate "Action" %}</th>
                        </tr>
                    </thead>
                    <tbody>
                        {% for svc in service_ctrls %}
                            {{ svc }}
                        {% endfor %}
                    </tbody>
                </table>
            </div>
        </div>
    </div>
{% endblock content %}
