{% load i18n %}
{% load humanize %}

{% block details %}

    <div class="panel panel-primary">
        <div class="panel-heading">
            <h3 class="panel-title">text</h3>
        </div>
        <div class="panel-body" style="min-height: 100px;">
            {{ text }}
        </div>
    </div>

{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
