@media all {
    * {
        color: rgb(78, 154, 6) !important;
        background-color: rgb(0, 0, 0) !important;
        background-image: none !important;
        border-color: rgba(78, 154, 6, 0.6) !important;
        font-family: monospace;
    }

    body {
        font-size: 1.125rem;
    }

    .nav-pills > li > a.active, .nav-pills > li > a:hover {
        background-color: rgba(78, 154, 6, 0.4) !important;
        color: rgb(0, 0, 0) !important;
    }

    .nav-pills > li > a.active i, .nav-pills > li > a:hover i {
        background-color: transparent !important;
        color: rgb(0, 0, 0) !important;
    }

    .template-dark-mode .nav-tabs > li.active > a {
        background-color: rgba(78, 154, 6, 0.4) !important;
        color: rgb(0, 0, 0) !important;
    }

    .badge {
        color: rgb(0, 0, 0) !important;
        background-color: rgba(78, 154, 6, 0.4) !important;
    }
}

/* AA Memberaudit
------------------------------------------------------------------------------------- */
@media all {
    .template-dark-mode .aa-memberaudit .nav-tabs > li.active > a {
        background-color: rgba(78, 154, 6, 0.4) !important;
        color: rgb(0, 0, 0) !important;
    }
}
