{% load static %}

<link rel="icon" type="image/png" href="{% static 'icons/terra-nanotech/favicon-16x16.png' %}" sizes="16x16">
<link rel="icon" type="image/png" href="{% static 'icons/terra-nanotech/favicon-32x32.png' %}" sizes="32x32">
<link rel="icon" type="image/png" href="{% static 'icons/terra-nanotech/favicon-96x96.png' %}" sizes="96x96">
<link rel="apple-touch-icon" href="{% static 'icons/terra-nanotech/apple-touch-icon.png' %}">
