{% extends "allianceauth/base.html" %}

{% load bootstrap %}
{% load static %}
{% load i18n %}

{% block page_title %}{% translate "Update AAR Link" %}{% endblock page_title %}

{% block content %}
    <h1 class="page-header text-center">{% translate "Update AAR Link" %}</h1>

    <div class="container-fluid">
        <div class="col-md-4 col-md-offset-4">
            <div class="row">
                {% if no_fleet_id %}
                    <div class="alert alert-danger" role="alert">{% translate "SRP Fleet Does Not Exist" %}</div>
                {% else %}
                    <form class="form-signin" role="form" action="" method="POST">
                        {% csrf_token %}
                        {{ form|bootstrap }}
                        <br/>
                        <button class="btn btn-lg btn-primary btn-block" type="submit">{% translate "Update AAR Link" %}
                        </button>
                    </form>
                {% endif %}
            </div>
        </div>
    </div>
{% endblock content %}
